﻿using UnityEngine;
using System.Collections;
using UnityEngine.Networking;

public class NetworkPlayer : NetworkBehaviour {
	[SyncVar(hook = "OnPlayerIDChanged")] public string playerID;
	[SyncVar(hook = "OnTeamChanged")] public int teamNumber;
	public Camera playerCam;
	Transform labelHolder;

	void Awake()
	{
		playerCam = GetComponentInChildren<Camera>();
		playerCam.gameObject.SetActive(false);
		labelHolder = transform.Find("LabelHolder");
	}

	[Command]
	void CmdSetPlayerID(string newID)
	{
		playerID = newID;
	}

	[Command]
	void CmdSetTeam(GameObject player)
	{
		TeamManager.SetPlayerTeam(gameObject);
	}

	public override void OnStartLocalPlayer ()
	{
		string myPlayerID = string.Format("Player {0}", netId.Value);
		CmdSetPlayerID(myPlayerID);
		playerCam.gameObject.SetActive(true);
		CmdSetTeam(gameObject); 
	}

	public override void OnStartClient ()
	{
		OnPlayerIDChanged(playerID);
		OnTeamChanged(teamNumber); 
	}

	void Update()
	{
		if(isLocalPlayer)
		{
			playerCam.transform.rotation = Quaternion.Euler(new Vector3(90,0,0));
		}

		labelHolder.rotation = Quaternion.identity;
	}

	void OnPlayerIDChanged(string newValue)
	{
		playerID = newValue;
		name = playerID;
		if(isLocalPlayer) name += " Local";
		var textMesh = labelHolder.Find("Label").GetComponent<TextMesh>();
		textMesh.text = newValue;
	}

	public void OnTeamChanged(int newTeamNumber)
	{
		teamNumber = newTeamNumber;
		GetComponent<Renderer>().material.color =  teamNumber == 0 ? Color.red : Color.blue;
	}

}